import { Component, OnInit, OnDestroy } from '@angular/core';
import { ContractService } from './services/contract.service';
import { Subscription } from 'rxjs';

@Component({
  selector: 'app-root',
  templateUrl: './app.component.html',
  styleUrls: ['./app.component.scss']
})
export class AppComponent implements OnInit, OnDestroy {
  title = 'DApp de Vote';
  
  isConnected = false;
  account: string | null = null;
  isOwner = false;
  isVoter = false;
  currentStatus = '0';
  loading = false;
  error: string | null = null;
  
  private subscriptions: Subscription[] = [];
  
  constructor(private contractService: ContractService) {}
  
  ngOnInit(): void {
    this.subscriptions.push(
      this.contractService.account$.subscribe(account => {
        this.account = account;
        this.isConnected = !!account;
      }),
      
      this.contractService.isOwner$.subscribe(isOwner => {
        this.isOwner = isOwner;
      }),
      
      this.contractService.isVoter$.subscribe(isVoter => {
        this.isVoter = isVoter;
      }),
      
      this.contractService.currentStatus$.subscribe(status => {
        this.currentStatus = status;
      }),
      
      this.contractService.loading$.subscribe(loading => {
        this.loading = loading;
      }),
      
      this.contractService.error$.subscribe(error => {
        this.error = error;
      })
    );
  }
  
  ngOnDestroy(): void {
    // Désabonnement de tous les observables
    this.subscriptions.forEach(sub => sub.unsubscribe());
  }
} 